@@ -7,11 +7,13 @@ information.
 """
 
 import logging
+
 logger = logging.getLogger("dialogs")
 
 from kb import KbError
 
 from dialogs.resources_manager import ResourcePool
+
 from dialogs.dialog_exceptions import UnsufficientInputError
 from dialogs.sentence import *
 from dialogs.sentence_factory import SentenceFactory
@@ -19,8 +21,8 @@ from dialogs.helpers.helpers import generate_id
 
 from random import choice
 
-class Discrimination():
 
+class Discrimination(object):
     def __init__(self):
         self.oro = ResourcePool().ontology_server
 
@@ -40,10 +42,10 @@ class Discrimination():
     # - None: no description (or description format incorrect)
     # -----------------------------------------------------------------------------#
     def get_all_objects_with_desc(self, description):
-        objL = None
-        
+        obj_list = None
+
         for agent_desc in description:
-            
+
             obj_tmp = []
 
             try:
@@ -54,16 +56,16 @@ class Discrimination():
                 pass
 
             # if no object found, no need to continue
-            if not obj_tmp: 
-                objL = []
+            if not obj_tmp:
+                obj_list = []
                 break
             else:
-                if objL == None:
-                    objL = obj_tmp
+                if obj_list is None:
+                    obj_list = obj_tmp
                 else:
-                    objL = filter(lambda x:x in objL,obj_tmp)  # intersection
+                    obj_list = filter(lambda x: x in obj_list, obj_tmp)  # intersection
 
-        return objL
+        return obj_list
 
     # -- GET_DISCRIMINANT ---------------------------------------------------------#
     # Queries the ontology for a list of discriminants. Returns the first one.
@@ -72,27 +74,26 @@ class Discrimination():
     # INPUT:
     # - agent
     # - object list
-    # - ignoreDesc: list of descriptors not to be used
-    # - zPartial: if true, then partial discriminants are also returned
+    # - ignore_descriptors: list of descriptors not to be used
+    # - include_partial: if true, then partial discriminants are also returned
     # OUTPUT:
     # - discriminant: [C, discriminat] if complete, or [P, discriminant] if partial
     #   The new discriminant should be different from the ones already known or ignored
     # -----------------------------------------------------------------------------#
-    def get_discriminant(self, agent, objL, ignoreDesc, zPartial):
-        discriminants = self.oro.discriminateForAgent(agent, objL)
-        logger.debug(  colored_print('Possible discriminants: ', 'magenta') +  \
-                        str(colored_print(discriminants[1], 'blue')) + \
-                        colored_print(" (complete discriminants: ", 'magenta') + \
-                        str(colored_print(discriminants[0], 'blue')) + ")")
+    def get_discriminant(self, agent, obj_list, ignore_descriptors, include_partial):
+        discriminants = self.oro.discriminateForAgent(agent, obj_list)
+        logger.debug(colored_print('Possible discriminants: ', 'magenta') + \
+                     str(colored_print(discriminants[1], 'blue')) + \
+                     colored_print(" (complete discriminants: ", 'magenta') + \
+                     str(colored_print(discriminants[0], 'blue')) + ")")
 
-
-        complete_disc = discriminants[0] 
+        complete_disc = discriminants[0]
         partial_disc = discriminants[1]
 
         if complete_disc:
-            res =  filter(lambda x: x not in ignoreDesc, complete_disc)
-        elif partial_disc and zPartial:
-            res = filter(lambda x: x not in ignoreDesc, partial_disc)
+            res = filter(lambda x: x not in ignore_descriptors, complete_disc)
+        elif partial_disc and include_partial:
+            res = filter(lambda x: x not in ignore_descriptors, partial_disc)
         else:
             res = None
 
@@ -110,38 +111,39 @@ class Discrimination():
     # - description: 
     #   [[agent1 '?obj' oro_query]..[[agentN '?obj' oro_query]]
     #   (oro_query= ['?obj hasColor blue',.. ?obj hasShape box'])
-    # - ignoreFeatureL: list of features not to use as discriminants
+    # - ignore_features: list of features not to use as discriminants
     #   [feat1 ..featN]
     # - allowPartialDesc: consider also partial discriminants (1) or not (0) (0 default)
     #
     # OUTPUT:
     # - descriptor or None (if no discriminant for any agent found)
     # -----------------------------------------------------------------------------#
-    def get_descriptor(self, description, ignoreFeatureL = [], partial_disc=True):
-        
+    def get_descriptor(self, description, ignore_features=None, partial_disc=True):
+
+        if not ignore_features: ignore_features = []
         objL = self.get_all_objects_with_desc(description)
         descriptor = None
         agent = None
 
         #TODO bug in oro doesn't allow to search discriminants base on other agents models!!
         # we cannot search in all agents, but only in robot's model
-#        for agent_desc in description:
-#            # list current descriptors to not to use them anymore
-#            #currentDescriptors = map(lambda x: x.split()[1], agent_desc[2])
-#            descriptor = self.get_discriminant(agent_desc[0], objL, ignoreFeatureL, partial_disc)
-#
-#            if descriptor:
-#                agent = agent_desc[0]
-#                break
+        #        for agent_desc in description:
+        #            # list current descriptors to not to use them anymore
+        #            #currentDescriptors = map(lambda x: x.split()[1], agent_desc[2])
+        #            descriptor = self.get_discriminant(agent_desc[0], objL, ignore_features, partial_disc)
+        #
+        #            if descriptor:
+        #                agent = agent_desc[0]
+        #                break
 
         agent = ResourcePool().default_model
         # list current descriptors to not to use them anymore
         #currentDescriptors = map(lambda x: x.split()[1], description[0][2])
-        descriptor = self.get_discriminant(agent, objL, ignoreFeatureL, partial_disc)
+        descriptor = self.get_discriminant(agent, objL, ignore_features, partial_disc)
 
         return agent, descriptor
 
-    
+
     # -- get_values_for_descriptor ------------------------------------------------#
     # Creates the information to be sent to user based on the discriminant found.
     #
@@ -169,7 +171,7 @@ class Discrimination():
             if val:
                 #TODO: we only consider the first result item!
                 valL.append(self.oro.getLabel(val[0]))
-            # otherwise, the object doesn't have this descriptor, and we don't include it
+                # otherwise, the object doesn't have this descriptor, and we don't include it
 
         # we make a set to remove repeated elements
         return list(set(valL))
@@ -188,19 +190,19 @@ class Discrimination():
 
         def find(value, seq):
             for item in seq:
-                itemL = item.split()
-                if value in itemL: 
-                    return itemL[2]
+                items = item.split()
+                if value in items:
+                    return items[2]
             return None
 
         type = None
-        
+
         for desc in description:
             type = find('rdf:type', desc[2])
             if type: break
-            
+
         return ResourcePool().ontology_server.getLabel(type)
-    
+
     # -- CLARIFY ------------------------------------------------------------------#
     # Searches for a new descriptor candidate. The descriptor should be as 
     # discriminating as possible.
@@ -217,21 +219,23 @@ class Discrimination():
     #   - [SUCCESS, "Which value? ..."]: user should indicate value for descriptor (mantain previous description)
     #   - [SUCCESS, "additional info required"]: user should give additional info (mantain previous description)
     # -----------------------------------------------------------------------------#
-    def clarify(self, description, ignoreFeatureL = []):
+    def clarify(self, description, ignoreFeatureL=None):
 
+        if not ignoreFeatureL: ignoreFeatureL = []
         objL = self.get_all_objects_with_desc(description)
 
         if len(objL) == 0:
             logger.debug(colored_print('Nothing found!', "magenta"))
         else:
-            logger.debug(colored_print('Found these possible concepts ID: ', "magenta") +  colored_print(str(objL), 'blue'))
+            logger.debug(
+                colored_print('Found these possible concepts ID: ', "magenta") + colored_print(str(objL), 'blue'))
 
         if not self.oro: #No ontology server
-            return 'UNKNOWN_CONCEPT_' + generate_id(with_question_mark = False)
+            return 'UNKNOWN_CONCEPT_' + generate_id(with_question_mark=False)
 
         if not objL:
             questions = SentenceFactory().create_i_dont_understand()
-            raise UnsufficientInputError({'status':'FAILURE', 'question':questions})
+            raise UnsufficientInputError({'status': 'FAILURE', 'question': questions})
             #return "I don't understand"
 
         else:
@@ -244,9 +248,9 @@ class Discrimination():
 
             if visible_objects:
                 objL = visible_objects
-                logger.debug(colored_print('Only ', "magenta") + 
-                            colored_print(str(objL), 'blue') +
-                            colored_print( " are visible by " + agent, "magenta"))
+                logger.debug(colored_print('Only ', "magenta") +
+                             colored_print(str(objL), 'blue') +
+                             colored_print(" are visible by " + agent, "magenta"))
             else:
                 logger.debug(colored_print('None are visible by ' + agent, "magenta"))
 
@@ -261,14 +265,14 @@ class Discrimination():
 
             if descriptor:
                 sentence_builder = SentenceFactory()
-                
+
                 question = None
                 values = self.get_values_for_descriptor(agent, descriptor, objL)
                 if not object: object = 'object'
-                
-                if descriptor == 'hasColor'  or  descriptor == 'mainColorOfObject':
+
+                if descriptor == 'hasColor' or descriptor == 'mainColorOfObject':
                     questions = sentence_builder.create_w_question_choice(object, 'color', values)
-                            
+
                 elif descriptor == 'hasShape':
                     questions = sentence_builder.create_w_question_choice(object, 'shape', values)
 
@@ -280,7 +284,7 @@ class Discrimination():
 
                 elif descriptor == 'isIn':
                     questions = sentence_builder.create_w_question_location(object, 'in', values)
-                    
+
                 elif descriptor == 'isNextTo':
                     questions = sentence_builder.create_w_question_location(object, 'next to', values)
 
@@ -289,24 +293,25 @@ class Discrimination():
 
                 elif descriptor == 'isLocated':
                     questions = sentence_builder.create_w_question_location_PT(values, agent)
-                
+
                 elif descriptor == 'rdf:type':
                     questions = sentence_builder.create_w_question_choice(object, 'type', values)
-                    
+
                 else:
                     questions = sentence_builder.create_w_question_generic_descriptor(object, descriptor, values)
 
-                raise UnsufficientInputError({'status':'SUCCESS','question':questions})
+                raise UnsufficientInputError({'status': 'SUCCESS', 'question': questions})
                 #return questions
-                    
+
             else:
-                questions = [Sentence(IMPERATIVE, '', [], 
-                            [Verbal_Group(['give'], [],'present simple', 
-                            [Nominal_Group([],['information'],[['more',[]]],[],[])], 
-                            [Indirect_Complement([],[Nominal_Group([],['me'],[],[],[])]),
-                            Indirect_Complement(['about'],[Nominal_Group(['the'],[object],[],[],[])])],
-                            [], [] ,Verbal_Group.affirmative,[])])]
-                raise UnsufficientInputError({'status':'SUCCESS','question':questions})
+                questions = [Sentence(IMPERATIVE, '', [],
+                                      [Verbal_Group(['give'], [], 'present simple',
+                                                    [Nominal_Group([], ['information'], [['more', []]], [], [])],
+                                                    [Indirect_Complement([], [Nominal_Group([], ['me'], [], [], [])]),
+                                                     Indirect_Complement(['about'], [
+                                                         Nominal_Group(['the'], [object], [], [], [])])],
+                                          [], [], Verbal_Group.affirmative, [])])]
+                raise UnsufficientInputError({'status': 'SUCCESS', 'question': questions})
                 #return "Give me more information about the object"
 
     def visible_subset(self, agent, id_list):
@@ -330,19 +335,19 @@ class Discrimination():
     # - new description
     # -----------------------------------------------------------------------------#
     def add_descriptor(self, agent, description, descriptor, value):
-        
+
         # return sublist index in seq containing value
         def find(value, seq):
             for index, item in enumerate(seq):
-                if value in item: 
+                if value in item:
                     return index, item
-                    
+
         idx, desc = find(agent, description)
         desc[2].append('?obj ' + descriptor + ' ' + value)
         description[idx] = desc
-        
+
         return description
-        
+
     # -- FIND_UNAMBIGUOUS_DESC ---------------------------------------#
     # Searches an unambiguous description for a given object. 
     # If it fails, it returns the most complete description found.
@@ -364,27 +369,27 @@ class Discrimination():
 
         # Not type asserted/inferred? then assume this object is unique.
         if not types:
-            return (True, [])
+            return True, []
 
         type = types[0]
 
         myself = ResourcePool().default_model
-        description = [[myself,'?obj',['?obj rdf:type ' + type]]]
+        description = [[myself, '?obj', ['?obj rdf:type ' + type]]]
         objL = self.get_all_objects_with_desc(description)
 
         while len(objL) > 1:
 
             nbCandidates = len(objL)
 
-            logger.debug('Description ' + objectID +': ' + str(description))
+            logger.debug('Description ' + objectID + ': ' + str(description))
             logger.debug('ObjL: ' + str(objL))
 
-            agent, descriptor = self.get_descriptor(description,[], True)
+            agent, descriptor = self.get_descriptor(description, [], True)
 
             if not descriptor:
                 break
 
-            val = self.oro.findForAgent(agent, '?val',[ objectID + ' ' + descriptor + ' ?val'])
+            val = self.oro.findForAgent(agent, '?val', [objectID + ' ' + descriptor + ' ?val'])
 
             if not val:
                 break
@@ -394,8 +399,8 @@ class Discrimination():
 
             if nbCandidates == len(objL):
                 logger.error("While trying to find an unambiguous description" + \
-                        " of " + objectID + ", oro answered a non-discriminant" + \
-                        " property. Bug in oro? Halting here for now.")
+                             " of " + objectID + ", oro answered a non-discriminant" + \
+                             " property. Bug in oro? Halting here for now.")
                 break
 
         if len(objL) == 1:
@@ -403,4 +408,4 @@ class Discrimination():
         else:
             unambiguous = False
 
-        return (unambiguous, description[0][2])
+        return unambiguous, description[0][2]
