@@ -1,4 +1,6 @@
+# coding=utf-8
 import logging
+
 logger = logging.getLogger("dialogs")
 
 from dialogs.helpers.helpers import colored_print
@@ -12,9 +14,9 @@ from dialogs.sentence_factory import SentenceFactory
 from dialogs.resources_manager import ResourcePool
 from dialogs.dialog_exceptions import DialogError, GrammaticalError
 
-class QuestionHandler:
 
-    def __init__(self, current_speaker = None):
+class QuestionHandler(object):
+    def __init__(self, current_speaker=None):
         self._sentence = None
         self._statements = []
         self._current_speaker = current_speaker
@@ -57,56 +59,63 @@ class QuestionHandler:
         #StatementBuilder
         builder = StatementBuilder(self._current_speaker)
         self._statements, situation_id = builder.process_sentence(self._sentence)
-        logger.info(level_marker(level=2, color="yellow") + "Generated statements based on the sentence components: " + colored_print(str(self._statements), None, "magenta"))
+        logger.info(level_marker(level=2,
+                                 color="yellow") + "Generated statements based on the sentence components: " + colored_print(
+            str(self._statements), None, "magenta"))
 
         #Case the question is a y_n_question : check the fact in the ontology
         if sentence.data_type == YES_NO_QUESTION:
             self._statements = self._set_situation_id(self._statements)
-            logger.info(level_marker(level=2, color="yellow") + "Generated statements for this question: " + colored_print(str(self._statements), None, "magenta"))
+            logger.info(
+                level_marker(level=2, color="yellow") + "Generated statements for this question: " + colored_print(
+                    str(self._statements), None, "magenta"))
             #Processing :Do you know something?
             if self.process_on_knowing_concept:
                 #self._statements = [agent knows object]
                 for s in self._statements:
-                    self._answer= True
-                    
+                    self._answer = True
+
                     if "knows" in s:
-                        [agent, object] = s.split( " knows ")
-                    
+                        [agent, object] = s.split(" knows ")
+
                         onto_lookup = []
                         try:
-                            logger.debug(level_marker(level=2, color="yellow") + "Looking up for " + object + " in " + agent +"'s model")
+                            logger.debug(level_marker(level=2,
+                                                      color="yellow") + "Looking up for " + object + " in " + agent + "'s model")
                             onto_lookup = ResourcePool().ontology_server.lookupForAgent(agent, object)
                         except AttributeError:
                             pass
-                            
+
                         self._answer = self._answer and (True if onto_lookup else False)
-                        
+
                 self.process_on_knowing_concept = False
             else:
                 try:
-                    logger.debug(level_marker(level=2, color="yellow") + "Checking in the ontology: " + colored_print(str(self._statements), None, "magenta"))
+                    logger.debug(level_marker(level=2, color="yellow") + "Checking in the ontology: " + colored_print(
+                        str(self._statements), None, "magenta"))
                     self._answer = ResourcePool().ontology_server.check(self._statements)
                 except AttributeError: #the ontology server is not started of doesn't know the method
                     pass
-                
+
         #Case the question is a w_question : find the concept the concept that answers the question
         if sentence.data_type == W_QUESTION:
             #
             self._query_on_field = self._set_query_on_field(sentence)
-            statements_with_bound_tokens =  self._remove_statements_with_no_unbound_tokens(self._statements)
-            
+            statements_with_bound_tokens = self._remove_statements_with_no_unbound_tokens(self._statements)
+
             #Agent from which the ontology model is queried
             agent = self._default_agent
-            
+
             self._answer = []
 
             #For all the possible subjects of a same question
             if not self._sentence.sn:
                 statements_to_query = [self._extend_statement_from_sentence_aim(statements_with_bound_tokens)]
-            
+
             else:
-                statements_to_query = [self._extend_statement_from_sentence_aim(statements_with_bound_tokens, sn) for sn in self._sentence.sn]
-            
+                statements_to_query = [self._extend_statement_from_sentence_aim(statements_with_bound_tokens, sn) for sn
+                                       in self._sentence.sn]
+
             for statements in statements_to_query:
                 if self.process_on_knowing_concept:
                     #Get agent in a statement such as [agent knows object]
@@ -120,15 +129,17 @@ class QuestionHandler:
                     self.process_on_knowing_concept = False
 
                 if statements:
-                    logger.info(level_marker(level=2, color="yellow") + "Generated statements for this question: " + colored_print(str(self._statements), None, "magenta"))
+                    logger.info(level_marker(level=2,
+                                             color="yellow") + "Generated statements for this question: " + colored_print(
+                        str(self._statements), None, "magenta"))
 
                     answers = []
                     if self._process_on_location:
 
                         prepositions_list = ResourcePool().preposition_rdf_object_property.copy()
-                        roles = dict([(preposition,prepositions_list[preposition][0])\
-                                for preposition in prepositions_list.keys()\
-                                 if 'objectFoundInLocation' in prepositions_list[preposition]])
+                        roles = dict([(preposition, prepositions_list[preposition][0]) \
+                                      for preposition in prepositions_list.keys() \
+                                      if 'objectFoundInLocation' in prepositions_list[preposition]])
 
                         #Case of ojectFound in location
                         stmts = []
@@ -139,8 +150,10 @@ class QuestionHandler:
 
                             stmts = [s.replace('objectFoundInLocation', roles[role]) for s in statements]
                             try:
-                                logger.debug(level_marker(level=2, color="yellow") + "Searching in "+ agent +" model: " + colored_print(str(stmts), None, "magenta"))
-                                answers = ResourcePool().ontology_server.findForAgent(agent,'?concept', stmts)
+                                logger.debug(level_marker(level=2,
+                                                          color="yellow") + "Searching in " + agent + " model: " + colored_print(
+                                    str(stmts), None, "magenta"))
+                                answers = ResourcePool().ontology_server.findForAgent(agent, '?concept', stmts)
                             except AttributeError: #the ontology server is not started of doesn't know the method
                                 pass
 
@@ -152,10 +165,14 @@ class QuestionHandler:
 
                         #Case of object found in location + direction
                         stmts = [s.replace('objectFoundInLocation', 'isAt') for s in statements]
-                        for role in ResourcePool().direction_words:                        
+                        for role in ResourcePool().direction_words:
                             try:
-                                logger.debug(level_marker(level=2, color="yellow") + "Searching in "+ agent +" model: " + colored_print(str(stmts + ['?concept is'+ role.capitalize() + 'Of ?obj', '?concept rdf:type Location']), None, "magenta"))
-                                answers = ResourcePool().ontology_server.findForAgent(agent,'?obj', stmts + ['?concept is'+ role.capitalize() + 'Of ?obj', '?concept rdf:type Location'])
+                                logger.debug(level_marker(level=2,
+                                                          color="yellow") + "Searching in " + agent + " model: " + colored_print(
+                                    str(stmts + ['?concept is' + role.capitalize() + 'Of ?obj',
+                                                 '?concept rdf:type Location']), None, "magenta"))
+                                answers = ResourcePool().ontology_server.findForAgent(agent, '?obj', stmts + [
+                                    '?concept is' + role.capitalize() + 'Of ?obj', '?concept rdf:type Location'])
                             except AttributeError: #the ontology server is not started of doesn't know the method
                                 pass
 
@@ -165,7 +182,9 @@ class QuestionHandler:
 
                     else:
                         try:
-                            logger.debug(level_marker(level=2, color="yellow") + "Searching in "+ agent +" model: " + colored_print(str(statements), None, "magenta"))
+                            logger.debug(level_marker(level=2,
+                                                      color="yellow") + "Searching in " + agent + " model: " + colored_print(
+                                str(statements), None, "magenta"))
                             answers = ResourcePool().ontology_server.findForAgent(agent, '?concept', statements)
                         except AttributeError: #the ontology server is not started of doesn't know the method
                             pass
@@ -180,9 +199,9 @@ class QuestionHandler:
 
         stmts, sit_id = self._build_situation_statements()
         return self._answer, stmts, sit_id
-    
+
     def _build_situation_statements(self):
-        sit_id = generate_id(with_question_mark = False)
+        sit_id = generate_id(with_question_mark=False)
 
         stmts = ["%s experiences %s" % (self._current_speaker, sit_id)]
         stmts += ["%s rdf:type InterrogativeState" % sit_id]
@@ -192,88 +211,89 @@ class QuestionHandler:
         stmts += ["%s hasAnswer %s" % (sit_id, "true" if self._answer else "false")]
 
         return stmts, sit_id
-    
+
     def _set_situation_id(self, statements):
         """This attempts to clarify the ID of an action verbs
             E.g: statement = [?event rdf:type Go, ?event performedBy myself, ?event actsOnObject xxx]
                 We attemtps to find an existing ontology ID matching '?event'
         """
         stmts = []
-        
+
         find_id = False
         for s in statements:
             if '?' in s:
                 find_id = True
                 break
-        
+
         if find_id:
             try:
                 sit_id = ResourcePool().ontology_server.find(['?event'], statements)
             except AttributeError: #the ontology server is not started of doesn't know the method
                 pass
-                
+
             if sit_id:
-                logger.debug("\t/Found a staticSituation matching the yes_no_question query to be checked: "+ str(sit_id))
+                logger.debug(
+                    "\t/Found a staticSituation matching the yes_no_question query to be checked: " + str(sit_id))
                 for s in statements:
                     #TODO:the ontology might find severals sit ID matching the query. Should we take this consideration?
                     #The longer the query, the better the result of sit_id
                     stmts.append(s.replace('?event', sit_id[0]))
         else:
             stmts = statements
-        
+
         # Find process on knowing concept
         for s in statements:
             if "knows" in s:
                 self.process_on_knowing_concept = True
                 break
-            
+
         return stmts
-    
-    
-    def _extend_statement_from_sentence_aim(self, current_statements, sn = None):
+
+
+    def _extend_statement_from_sentence_aim(self, current_statements, sn=None):
         """This extends the statements states so that the query answer matches the w_question aim
         
         """
         #Concept descriptor
         # E.g: Human, Object, Color ,Size...
         concept_descriptor = self.get_concept_descriptor(sn)
-        
+
         #Case: the statement is complete from statement builder e.g: what is in the box? =>[?concept isIn ?id_box, ?id_box rdf:type Box]
         for s in current_statements:
             if '?concept' in s.split():
                 return current_statements + concept_descriptor
-        #case: the statement is partially build from statement builder
-        
+                #case: the statement is partially build from statement builder
+
         stmts = []
         if sn:
             for sv in self._sentence.sv:
                 for verb in sv.vrb_main:
-                    role  = self.get_role_from_sentence_aim(self._query_on_field, verb)
-                    
+                    role = self.get_role_from_sentence_aim(self._query_on_field, verb)
+
                     #Case of looking for the object in a location
                     if role == 'objectFoundInLocation':
                         self._process_on_location = True
-                    
+
                     # Case of state verbs
                     if verb.lower() in ResourcePool().state:
-                        stmts.append(sn.id + ' '+ role + ' ?concept')
+                        stmts.append(sn.id + ' ' + role + ' ?concept')
                     # Case of action verb with a passive behaviour
                     elif verb.lower() in ResourcePool().action_verb_with_passive_behaviour.keys():
-                        stmts.append(sn.id + ' '+ ResourcePool().action_verb_with_passive_behaviour[verb.lower()] + ' ?concept')
-                    
+                        stmts.append(
+                            sn.id + ' ' + ResourcePool().action_verb_with_passive_behaviour[verb.lower()] + ' ?concept')
+
                     # Case of know
                     elif verb.lower() == 'know':
                         self.process_on_knowing_concept = True
                         stmts.append(sn.id + ' knows ?concept')
-                    
+
                     # case of action verbs
                     else:
                         stmts.append('?event ' + role + ' ?concept')
-                    
+
         return current_statements + stmts + concept_descriptor
-    
-    
-    
+
+
     def _set_query_on_field(self, sentence):
         """ This defines which part of a sentence is supposed to be completed once the answer of a w_question has been retrieved
             E:g - [W_question] : where is the cube
@@ -284,21 +304,20 @@ class QuestionHandler:
         """
         if sentence.aim == 'place':
             return 'QUERY_ON_INDIRECT_OBJ'
-        
+
         if not sentence.sn:
             return None
-                   
+
         if sentence.sv:
             if not sentence.sv[0].d_obj:
                 query_on_field = 'QUERY_ON_DIRECT_OBJ'
-            
+
             else:
                 query_on_field = 'QUERY_ON_INDIRECT_OBJ'
-        
+
         return query_on_field
-        
-            
-    
+
+
     def get_role_from_sentence_aim(self, query_on_field, verb):
         """ Given specific w_question aim and verb, this function attempts to define the matching object property to built
             an RDF tuple <S P O>. Cf. QuestionAimDict() for more detail.
@@ -314,10 +333,10 @@ class QuestionHandler:
                 role = dic_aim[self._sentence.aim][None][verb.lower()]
             else:
                 role = dic_aim[self._sentence.aim][None][None]
-    
+
         return role
-    
-    
+
+
     def get_concept_descriptor(self, ng):
         """ Get the type or feature of the concept to query if it is not mapped in the QuestionAimDict
             E.g: What color is the bottle?
@@ -329,17 +348,17 @@ class QuestionHandler:
                 We return it in concept_descriptor = '?concept rdf:type Human'
                 
         """
-        
+
         concept_descriptor = []
         agent = self._default_agent
         aim = self._sentence.aim
-        
+
         #Concept's Features
         if self._sentence.aim in ResourcePool().adjectives_ontology_classes:
             if ng:
                 concept_descriptor = [ng.id + " has" + aim.capitalize() + " ?concept"]
                 self._sentence.aim = "thing"
-        
+
         #Concept's Type
         elif not self._sentence.aim in QuestionAimDict().dic_aim.keys():
             logger.debug("\tFound the aim: " + aim + ".Extending statements with [?concept rdf:type aim]")
@@ -347,16 +366,16 @@ class QuestionHandler:
                 onto = ResourcePool().ontology_server.lookupForAgent(agent, aim)
             except AttributeError:
                 onto = None
-                
+
             concept_descriptor = ["?concept rdf:type " + get_class_name(aim, onto)]
             self._sentence.aim = "thing"
-            
+
         elif self._sentence.aim == "people":
             concept_descriptor = ["?concept rdf:type Agent"]
-        
+
         return concept_descriptor
-            
-        
+
+
     """            
         what aim => 'thing'
             what kind => aim = 'thing', sn = [the kind of]
@@ -376,20 +395,20 @@ class QuestionHandler:
              how often => aim = 'Frequency'
              How much  => aim = 'Quantity'
             How many  => aim = 'Quantity'
-    """    
+    """
+
 
-    
     def _remove_statements_with_no_unbound_tokens(self, statements):
         """ This remove statement part with no unbound token, for querying the ontology."""
         stmts = []
         for s in statements:
             if '?' in s:
                 stmts.append(s)
-                
-        return stmts
-    
 
-class QuestionAimDict:
+        return stmts
+
+
+class QuestionAimDict(object):
     def __init__(self):
         """
         This class consits in building a map of object property regarding the 
@@ -428,34 +447,36 @@ class QuestionAimDict:
             Case # query_on_field = 'QUERY_ON_INDIRECT_OBJ'
                 extend statements with [* objectFoundInLocation ?concept]  
         """
-        
+
         self.dic_aim = {}
-        
-        
+
+
         #Dictionaries related to thematice roles verbs
         verbs_dic = ResourcePool().thematic_roles.verbs
-        self.dic_on_direct_obj = dict([(verb , role.id) for verb in verbs_dic.keys() for role in verbs_dic[verb].roles[0:1]])
+        self.dic_on_direct_obj = dict(
+            [(verb, role.id) for verb in verbs_dic.keys() for role in verbs_dic[verb].roles[0:1]])
         self.dic_on_direct_obj[None] = 'involves'
         self.dic_on_direct_obj['be'] = 'owl:sameAs'
-        
-        self.dic_on_indirect_obj = dict([(verb , role.id) for verb in verbs_dic.keys() for role in verbs_dic[verb].roles[1:2]])
+
+        self.dic_on_indirect_obj = dict(
+            [(verb, role.id) for verb in verbs_dic.keys() for role in verbs_dic[verb].roles[1:2]])
         self.dic_on_indirect_obj['be'] = None
         self.dic_on_indirect_obj[None] = 'owl:sameAs'
-    
+
         #Dictionary for sentence.aim = 'place' 
-        self.dic_place={None:self.dic_on_indirect_obj.copy()}
+        self.dic_place = {None: self.dic_on_indirect_obj.copy()}
         self.dic_place[None]['be'] = 'objectFoundInLocation'
-                        
+
         #Dictionary for sentence.aim = 'thing' 
-        self.dic_thing={None:self.dic_on_direct_obj.copy()}
-                
+        self.dic_thing = {None: self.dic_on_direct_obj.copy()}
+
         #Dictionary for sentence.aim = 'manner' 
-        self.dic_manner={None:{'be':'owl:topObjectProperty'}}
-        
+        self.dic_manner = {None: {'be': 'owl:topObjectProperty'}}
+
         #Dictionary for sentence.aim = 'people'
-        self.dic_people={'QUERY_ON_DIRECT_OBJ':self.dic_on_direct_obj.copy(),                                                                                              
-                    'QUERY_ON_INDIRECT_OBJ':self.dic_on_indirect_obj.copy()}
-        
+        self.dic_people = {'QUERY_ON_DIRECT_OBJ': self.dic_on_direct_obj.copy(),
+                           'QUERY_ON_INDIRECT_OBJ': self.dic_on_indirect_obj.copy()}
+
         #Dictionary for all question aims        
         #What-question
         self.dic_aim['thing'] = self.dic_thing
